>From 08f3a0c9b112e3d00e2fc22c9dccc5a9d389dbc1 Mon Sep 17 00:00:00 2001
From: Stefan Tauner <stefan.tauner@student.tuwien.ac.at>
Date: Sat, 12 Nov 2011 22:44:26 +0100
Subject: [PATCH] ichspi: fix ich_init_opcodes() calls in ich_init_spi()

By calling it early ichspi_lock was not set up correctly in accordance
with the corresponding register, hence ich_init_opcodes() was always
trying to programming the opcodes instead of reading them in from the
opmenu in case of a locked down configuration.

Thanks to Jonathan Kollasch for reporting this bug.

Signed-off-by: Stefan Tauner <stefan.tauner@student.tuwien.ac.at>
Acked-by: Stefan Tauner <stefan.tauner@student.tuwien.ac.at>
---
 ichspi.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/ichspi.c b/ichspi.c
index c684522..9103735 100644
--- a/ichspi.c
+++ b/ichspi.c
@@ -1562,8 +1562,6 @@ int ich_init_spi(struct pci_dev *dev, uint32_t base, void *rcrb,
 	/* Assign Virtual Address */
 	ich_spibar = rcrb + spibar_offset;
 
-	ich_init_opcodes();
-
 	switch (ich_generation) {
 	case CHIPSET_ICH7:
 		msg_pdbg("0x00: 0x%04x     (SPIS)\n",
@@ -1601,6 +1599,7 @@ int ich_init_spi(struct pci_dev *dev, uint32_t base, void *rcrb,
 			msg_pinfo("WARNING: SPI Configuration Lockdown activated.\n");
 			ichspi_lock = 1;
 		}
+		ich_init_opcodes();
 		ich_set_bbar(0);
 		register_spi_programmer(&spi_programmer_ich7);
 		break;
@@ -1643,6 +1642,7 @@ int ich_init_spi(struct pci_dev *dev, uint32_t base, void *rcrb,
 				  "by the FRAP and FREG registers are NOT in "
 				  "effect. Please note that Protected\n"
 				  "Range (PR) restrictions still apply.\n");
+		ich_init_opcodes();
 
 		if (desc_valid) {
 			tmp2 = mmio_readw(ich_spibar + ICH9_REG_HSFC);
-- 
1.7.1

